Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(355)

Unified Diff: remoting/host/client_session_unittest.cc

Issue 455073004: Switch DesktopEnvironment to return a DesktopCapturer. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Remove ShapedDesktopCapturer::Create() Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « remoting/host/client_session.cc ('k') | remoting/host/desktop_environment.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: remoting/host/client_session_unittest.cc
diff --git a/remoting/host/client_session_unittest.cc b/remoting/host/client_session_unittest.cc
index 112afbf34e1d184138763d276ac52986ca8b906f..b3dfa45396606fc3f1f086191c026bf284bfe2dc 100644
--- a/remoting/host/client_session_unittest.cc
+++ b/remoting/host/client_session_unittest.cc
@@ -15,9 +15,9 @@
#include "remoting/host/audio_capturer.h"
#include "remoting/host/client_session.h"
#include "remoting/host/desktop_environment.h"
+#include "remoting/host/fake_desktop_capturer.h"
#include "remoting/host/fake_host_extension.h"
#include "remoting/host/fake_mouse_cursor_monitor.h"
-#include "remoting/host/fake_screen_capturer.h"
#include "remoting/host/host_extension.h"
#include "remoting/host/host_extension_session.h"
#include "remoting/host/host_mock_objects.h"
@@ -135,7 +135,7 @@ class ClientSessionTest : public testing::Test {
void StopClientSession();
protected:
// Creates a DesktopEnvironment with a fake webrtc::ScreenCapturer, to mock
// DesktopEnvironmentFactory::Create().
DesktopEnvironment* CreateDesktopEnvironment();
@@ -143,9 +143,9 @@ class ClientSessionTest : public testing::Test {
// DesktopEnvironment::CreateInputInjector().
InputInjector* CreateInputInjector();
// Creates a fake webrtc::ScreenCapturer, to mock
// DesktopEnvironment::CreateVideoCapturer().
- webrtc::ScreenCapturer* CreateVideoCapturer();
+ webrtc::DesktopCapturer* CreateVideoCapturer();
// Creates a MockMouseCursorMonitor, to mock
// DesktopEnvironment::CreateMouseCursorMonitor
@@ -301,8 +301,8 @@ InputInjector* ClientSessionTest::CreateInputInjector() {
return input_injector_.release();
}
-webrtc::ScreenCapturer* ClientSessionTest::CreateVideoCapturer() {
- return new FakeScreenCapturer();
+webrtc::DesktopCapturer* ClientSessionTest::CreateVideoCapturer() {
+ return new FakeDesktopCapturer();
}
webrtc::MouseCursorMonitor* ClientSessionTest::CreateMouseCursorMonitor() {
@@ -596,9 +596,9 @@ TEST_F(ClientSessionTest, ClampMouseEvents) {
Expectation connected = authenticated;
int input_x[3] = { -999, 100, 999 };
- int expected_x[3] = { 0, 100, FakeScreenCapturer::kWidth - 1 };
+ int expected_x[3] = { 0, 100, FakeDesktopCapturer::kWidth - 1 };
int input_y[3] = { -999, 50, 999 };
- int expected_y[3] = { 0, 50, FakeScreenCapturer::kHeight - 1 };
+ int expected_y[3] = { 0, 50, FakeDesktopCapturer::kHeight - 1 };
protocol::MouseEvent expected_event;
for (int j = 0; j < 3; j++) {
« no previous file with comments | « remoting/host/client_session.cc ('k') | remoting/host/desktop_environment.h » ('j') | no next file with comments »
@@ -135,7 +135,7 @@ class ClientSessionTest : public testing::Test {
void StopClientSession();
protected:
- // Creates a DesktopEnvironment with a fake webrtc::ScreenCapturer, to mock
+ // Creates a DesktopEnvironment with a fake webrtc::DesktopCapturer, to mock
// DesktopEnvironmentFactory::Create().
DesktopEnvironment* CreateDesktopEnvironment();
@@ -143,9 +143,9 @@ class ClientSessionTest : public testing::Test {
// DesktopEnvironment::CreateInputInjector().
InputInjector* CreateInputInjector();
- // Creates a fake webrtc::ScreenCapturer, to mock
+ // Creates a fake webrtc::DesktopCapturer, to mock
// DesktopEnvironment::CreateVideoCapturer().

Powered by Google App Engine
This is Rietveld 408576698